import os

class Config(metaclass=Singleton):
    FIELD_VALUE = 0
    FIELD_DESCRIPTION = 1

    baseConfigFileName = '../base.cfg'
    def __init__(self):
        self.configs = self.__load()

    def __load(self):
        configs = {}
        if os.path.exists(self.baseConfigFileName):
            with open(self.baseConfigFileName, 'r') as f:
                data = f.read().split('\n')
            for d in data:
                description = ''
                if '#' in d:
                    _d = d.split('#')
                    description = _d[1]
                    d = _d[0]
                d = d.split('=')
                key = d[0].replace(' ', '')
                value = d[1].strip()
                configs[key] = (value, description)
        return configs       

    def getValue(self, key):
        try:
            return self.getValueAndDescription(key)[0]
        except Exception as e:
            raise e

    def getDescription(self, key):
        try:
            return self.getValueAndDescription(key)[1]
        except Exception as e:
            raise e

    def getValueAndDescription(self, key):
        if key in list(self.configs.keys()):
            return self.configs[key]
        raise Exception('No Config Key')

if __name__ == '__main__':
    config = Config()
    print (config.getValue('StockDailyDataPath'))
    print (config.getDescription('StockDailyDataPath'))


from threading import Lock

class Singleton(type):
    _instance = None
    _lock = Lock()

    def __call__(cls, *args, **kwargs):
        with cls._lock:
            if not cls._instance:
                cls._instance = super().__call__(*args, **kwargs)
        return cls._instance


import setuptools

setuptools.setup(
    name="taejisutil",
    version="0.1.2",
    license='MIT',
    author="cheolgi",
    author_email="mobilechos@gmail.com",
    description="utils",
    long_description=open('README.md').read(),
    url="http://www.mobilechos.com",
    packages=setuptools.find_packages(),
    classifiers=[
        # 패키지에 대한 태그
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ],
)